@@ -7,9 +7,9 @@
 #ifndef ADDDIALOG_H
 #define ADDDIALOG_H
 
-#include "kerfuffle_export.h"
 #include "archive_kerfuffle.h"
 #include "compressionoptionswidget.h"
+#include "kerfuffle_export.h"
 
 #include <KFileWidget>
 
@@ -24,11 +24,7 @@ class KERFUFFLE_EXPORT AddDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit AddDialog(QWidget *parent,
-                       const QString &title,
-                       const QUrl &startDir,
-                       const QMimeType &mimeType,
-                       const CompressionOptions &opts = {});
+    explicit AddDialog(QWidget *parent, const QString &title, const QUrl &startDir, const QMimeType &mimeType, const CompressionOptions &opts = {});
     ~AddDialog() override;
     QStringList selectedFiles() const;
     CompressionOptions compressionOptions() const;
