@@ -10,8 +10,8 @@
 #include "archivemodel.h"
 #include "ark_debug.h"
 #include "jobs.h"
-#include "util.h"
 #include "qstringtokenizer.h"
+#include "util.h"
 
 #include <KIO/Global>
 #include <KLocalizedString>
@@ -40,18 +40,18 @@ ArchiveModel::ArchiveModel(const QString &dbusPathName, QObject *parent)
 
     // Mappings between column indexes and entry properties.
     m_propertiesMap = {
-        { DisplayName, "displayName" },
-        { Size, "size" },
-        { CompressedSize, "compressedSize" },
-        { Permissions, "permissions" },
-        { Owner, "owner" },
-        { Group, "group" },
-        { Ratio, "ratio" },
-        { CRC, "CRC" },
-        { BLAKE2, "BLAKE2" },
-        { Method, "method" },
-        { Version, "version" },
-        { Timestamp, "timestamp" },
+        {DisplayName, "displayName"},
+        {Size, "size"},
+        {CompressedSize, "compressedSize"},
+        {Permissions, "permissions"},
+        {Owner, "owner"},
+        {Group, "group"},
+        {Ratio, "ratio"},
+        {CRC, "CRC"},
+        {BLAKE2, "BLAKE2"},
+        {Method, "method"},
+        {Version, "version"},
+        {Timestamp, "timestamp"},
     };
 }
 
@@ -62,7 +62,7 @@ ArchiveModel::~ArchiveModel()
 QVariant ArchiveModel::data(const QModelIndex &index, int role) const
 {
     if (index.isValid()) {
-        Archive::Entry *entry = static_cast<Archive::Entry*>(index.internalPointer());
+        Archive::Entry *entry = static_cast<Archive::Entry *>(index.internalPointer());
         switch (role) {
         case Qt::DisplayRole: {
             // TODO: complete the columns.
@@ -112,7 +112,7 @@ QVariant ArchiveModel::data(const QModelIndex &index, int role) const
         }
         case Qt::DecorationRole:
             if (index.column() == 0) {
-                Archive::Entry *e = static_cast<Archive::Entry*>(index.internalPointer());
+                Archive::Entry *e = static_cast<Archive::Entry *>(index.internalPointer());
                 QIcon::Mode mode = (filesToMove.contains(e->fullPath())) ? QIcon::Disabled : QIcon::Normal;
                 return e->icon().pixmap(QApplication::style()->pixelMetric(QStyle::PM_SmallIconSize), mode);
             }
@@ -143,8 +143,7 @@ QVariant ArchiveModel::headerData(int section, Qt::Orientation, int role) const
 {
     if (role == Qt::DisplayRole) {
         if (section >= m_showColumns.size()) {
-            qCDebug(ARK) << "WEIRD: showColumns.size = " << m_showColumns.size()
-            << " and section = " << section;
+            qCDebug(ARK) << "WEIRD: showColumns.size = " << m_showColumns.size() << " and section = " << section;
             return QVariant();
         }
 
@@ -186,15 +185,13 @@ QVariant ArchiveModel::headerData(int section, Qt::Orientation, int role) const
 QModelIndex ArchiveModel::index(int row, int column, const QModelIndex &parent) const
 {
     if (hasIndex(row, column, parent)) {
-        const Archive::Entry *parentEntry = parent.isValid()
-                                            ? static_cast<Archive::Entry*>(parent.internalPointer())
-                                            : m_rootEntry.data();
+        const Archive::Entry *parentEntry = parent.isValid() ? static_cast<Archive::Entry *>(parent.internalPointer()) : m_rootEntry.data();
 
         Q_ASSERT(parentEntry->isDir());
 
         const Archive::Entry *item = parentEntry->entries().value(row, nullptr);
         if (item != nullptr) {
-            return createIndex(row, column, const_cast<Archive::Entry*>(item));
+            return createIndex(row, column, const_cast<Archive::Entry *>(item));
         }
     }
 
@@ -204,7 +201,7 @@ QModelIndex ArchiveModel::index(int row, int column, const QModelIndex &parent)
 QModelIndex ArchiveModel::parent(const QModelIndex &index) const
 {
     if (index.isValid()) {
-        Archive::Entry *item = static_cast<Archive::Entry*>(index.internalPointer());
+        Archive::Entry *item = static_cast<Archive::Entry *>(index.internalPointer());
         Q_ASSERT(item);
         if (item->getParent() && (item->getParent() != m_rootEntry.data())) {
             return createIndex(item->getParent()->row(), 0, item->getParent());
@@ -216,7 +213,7 @@ QModelIndex ArchiveModel::parent(const QModelIndex &index) const
 Archive::Entry *ArchiveModel::entryForIndex(const QModelIndex &index)
 {
     if (index.isValid()) {
-        Archive::Entry *item = static_cast<Archive::Entry*>(index.internalPointer());
+        Archive::Entry *item = static_cast<Archive::Entry *>(index.internalPointer());
         Q_ASSERT(item);
         return item;
     }
@@ -226,9 +223,7 @@ Archive::Entry *ArchiveModel::entryForIndex(const QModelIndex &index)
 int ArchiveModel::rowCount(const QModelIndex &parent) const
 {
     if (parent.column() <= 0) {
-        const Archive::Entry *parentEntry = parent.isValid()
-                                            ? static_cast<Archive::Entry*>(parent.internalPointer())
-                                            : m_rootEntry.data();
+        const Archive::Entry *parentEntry = parent.isValid() ? static_cast<Archive::Entry *>(parent.internalPointer()) : m_rootEntry.data();
 
         if (parentEntry && parentEntry->isDir()) {
             return parentEntry->entries().count();
@@ -253,13 +248,10 @@ QStringList ArchiveModel::mimeTypes() const
     QStringList types;
 
     // MIME types we accept for dragging (eg. Dolphin -> Ark).
-    types << QStringLiteral("text/uri-list")
-          << QStringLiteral("text/plain")
-          << QStringLiteral("text/x-moz-url");
+    types << QStringLiteral("text/uri-list") << QStringLiteral("text/plain") << QStringLiteral("text/x-moz-url");
 
     // MIME types we accept for dropping (eg. Ark -> Dolphin).
-    types << QStringLiteral("application/x-kde-ark-dndextract-service")
-          << QStringLiteral("application/x-kde-ark-dndextract-path");
+    types << QStringLiteral("application/x-kde-ark-dndextract-service") << QStringLiteral("application/x-kde-ark-dndextract-path");
 
     return types;
 }
@@ -269,10 +261,8 @@ QMimeData *ArchiveModel::mimeData(const QModelIndexList &indexes) const
     Q_UNUSED(indexes)
 
     QMimeData *mimeData = new QMimeData;
-    mimeData->setData(QStringLiteral("application/x-kde-ark-dndextract-service"),
-                      QDBusConnection::sessionBus().baseService().toUtf8());
-    mimeData->setData(QStringLiteral("application/x-kde-ark-dndextract-path"),
-                      m_dbusPathName.toUtf8());
+    mimeData->setData(QStringLiteral("application/x-kde-ark-dndextract-service"), QDBusConnection::sessionBus().baseService().toUtf8());
+    mimeData->setData(QStringLiteral("application/x-kde-ark-dndextract-path"), m_dbusPathName.toUtf8());
 
     return mimeData;
 }
@@ -285,9 +275,7 @@ bool ArchiveModel::dropMimeData(const QMimeData *data, Qt::DropAction action, in
         return false;
     }
 
-    if (archive()->isReadOnly() ||
-        (archive()->encryptionType() != Archive::Unencrypted &&
-         archive()->password().isEmpty())) {
+    if (archive()->isReadOnly() || (archive()->encryptionType() != Archive::Unencrypted && archive()->password().isEmpty())) {
         Q_EMIT messageWidget(KMessageWidget::Error, i18n("Adding files is not supported for this archive."));
         return false;
     }
@@ -317,7 +305,7 @@ bool ArchiveModel::dropMimeData(const QMimeData *data, Qt::DropAction action, in
 }
 
 // For a rationale, see bugs #194241, #241967 and #355839
-QString ArchiveModel::cleanFileName(const QString& fileName)
+QString ArchiveModel::cleanFileName(const QString &fileName)
 {
     // Skip entries with filename "/" or "//" or "."
     // "." is present in ISO files.
@@ -367,9 +355,9 @@ Archive::Entry *ArchiveModel::parentFor(const Archive::Entry *entry, InsertBehav
             // and then delete the existing one (see ArchiveModel::newEntry).
             entry = new Archive::Entry(parent);
 
-            entry->setProperty("fullPath", (parent == m_rootEntry.data())
-                                           ? QString(piece + QLatin1Char('/'))
-                                           : QString(parent->fullPath(WithTrailingSlash) + piece + QLatin1Char('/')));
+            entry->setProperty("fullPath",
+                               (parent == m_rootEntry.data()) ? QString(piece + QLatin1Char('/'))
+                                                              : QString(parent->fullPath(WithTrailingSlash) + piece + QLatin1Char('/')));
             entry->setProperty("isDirectory", true);
             insertEntry(entry, behaviour);
         }
@@ -400,7 +388,7 @@ QModelIndex ArchiveModel::indexForEntry(Archive::Entry *entry)
     return QModelIndex();
 }
 
-void ArchiveModel::slotEntryRemoved(const QString & path)
+void ArchiveModel::slotEntryRemoved(const QString &path)
 {
     const QString entryFileName(cleanFileName(path));
     if (entryFileName.isEmpty()) {
@@ -483,8 +471,7 @@ void ArchiveModel::newEntry(Archive::Entry *receivedEntry, InsertBehaviour behav
 
     // For some archive formats (e.g. AppImage and RPM) paths of folders do not
     // contain a trailing slash, so we append it.
-    if (receivedEntry->property("isDirectory").toBool() &&
-        !receivedEntry->property("fullPath").toString().endsWith(QLatin1Char('/'))) {
+    if (receivedEntry->property("isDirectory").toBool() && !receivedEntry->property("fullPath").toString().endsWith(QLatin1Char('/'))) {
         receivedEntry->setProperty("fullPath", QString(receivedEntry->property("fullPath").toString() + QLatin1Char('/')));
         qCDebug(ARK) << "Trailing slash appended to entry:" << receivedEntry->property("fullPath");
     }
@@ -519,10 +506,9 @@ void ArchiveModel::slotLoadingFinished(KJob *job)
     std::sort(m_showColumns.begin(), m_showColumns.end());
 
     if (!job->error()) {
-
         qCDebug(ARK) << "Showing columns: " << m_showColumns;
 
-        m_archive.reset(qobject_cast<LoadJob*>(job)->archive());
+        m_archive.reset(qobject_cast<LoadJob *>(job)->archive());
 
         beginResetModel();
         endResetModel();
@@ -545,7 +531,7 @@ void ArchiveModel::insertEntry(Archive::Entry *entry, InsertBehaviour behaviour)
     }
 }
 
-Kerfuffle::Archive* ArchiveModel::archive() const
+Kerfuffle::Archive *ArchiveModel::archive() const
 {
     return m_archive.data();
 }
@@ -583,13 +569,13 @@ Kerfuffle::LoadJob *ArchiveModel::loadArchive(const QString &path, const QString
     return loadJob;
 }
 
-ExtractJob* ArchiveModel::extractFile(Archive::Entry *file, const QString& destinationDir, Kerfuffle::ExtractionOptions options) const
+ExtractJob *ArchiveModel::extractFile(Archive::Entry *file, const QString &destinationDir, Kerfuffle::ExtractionOptions options) const
 {
-    QVector<Archive::Entry*> files({file});
+    QVector<Archive::Entry *> files({file});
     return extractFiles(files, destinationDir, options);
 }
 
-ExtractJob* ArchiveModel::extractFiles(const QVector<Archive::Entry*>& files, const QString& destinationDir, Kerfuffle::ExtractionOptions options) const
+ExtractJob *ArchiveModel::extractFiles(const QVector<Archive::Entry *> &files, const QString &destinationDir, Kerfuffle::ExtractionOptions options) const
 {
     Q_ASSERT(m_archive);
     ExtractJob *newJob = m_archive->extractFiles(files, destinationDir, options);
@@ -621,7 +607,7 @@ OpenWithJob *ArchiveModel::openWith(Archive::Entry *file) const
     return job;
 }
 
-AddJob* ArchiveModel::addFiles(QVector<Archive::Entry*> &entries, const Archive::Entry *destination, const CompressionOptions& options)
+AddJob *ArchiveModel::addFiles(QVector<Archive::Entry *> &entries, const Archive::Entry *destination, const CompressionOptions &options)
 {
     if (!m_archive) {
         return nullptr;
@@ -632,13 +618,12 @@ AddJob* ArchiveModel::addFiles(QVector<Archive::Entry*> &entries, const Archive:
         connect(job, &AddJob::newEntry, this, &ArchiveModel::slotNewEntry);
         connect(job, &AddJob::userQuery, this, &ArchiveModel::slotUserQuery);
 
-
         return job;
     }
     return nullptr;
 }
 
-Kerfuffle::MoveJob *ArchiveModel::moveFiles(QVector<Archive::Entry*> &entries, Archive::Entry *destination, const CompressionOptions &options)
+Kerfuffle::MoveJob *ArchiveModel::moveFiles(QVector<Archive::Entry *> &entries, Archive::Entry *destination, const CompressionOptions &options)
 {
     if (!m_archive) {
         return nullptr;
@@ -651,12 +636,11 @@ Kerfuffle::MoveJob *ArchiveModel::moveFiles(QVector<Archive::Entry*> &entries, A
         connect(job, &MoveJob::entryRemoved, this, &ArchiveModel::slotEntryRemoved);
         connect(job, &MoveJob::finished, this, &ArchiveModel::slotCleanupEmptyDirs);
 
-
         return job;
     }
     return nullptr;
 }
-Kerfuffle::CopyJob *ArchiveModel::copyFiles(QVector<Archive::Entry*> &entries, Archive::Entry *destination, const CompressionOptions &options)
+Kerfuffle::CopyJob *ArchiveModel::copyFiles(QVector<Archive::Entry *> &entries, Archive::Entry *destination, const CompressionOptions &options)
 {
     if (!m_archive) {
         return nullptr;
@@ -667,13 +651,12 @@ Kerfuffle::CopyJob *ArchiveModel::copyFiles(QVector<Archive::Entry*> &entries, A
         connect(job, &CopyJob::newEntry, this, &ArchiveModel::slotNewEntry);
         connect(job, &CopyJob::userQuery, this, &ArchiveModel::slotUserQuery);
 
-
         return job;
     }
     return nullptr;
 }
 
-DeleteJob* ArchiveModel::deleteFiles(QVector<Archive::Entry*> entries)
+DeleteJob *ArchiveModel::deleteFiles(QVector<Archive::Entry *> entries)
 {
     Q_ASSERT(m_archive);
     if (!m_archive->isReadOnly()) {
@@ -697,7 +680,7 @@ void ArchiveModel::encryptArchive(const QString &password, bool encryptHeader)
     m_archive->encrypt(password, encryptHeader);
 }
 
-bool ArchiveModel::conflictingEntries(QList<const Archive::Entry*> &conflictingEntries, const QStringList &entries, bool allowMerging) const
+bool ArchiveModel::conflictingEntries(QList<const Archive::Entry *> &conflictingEntries, const QStringList &entries, bool allowMerging) const
 {
     bool error = false;
 
@@ -743,8 +726,7 @@ bool ArchiveModel::conflictingEntries(QList<const Archive::Entry*> &conflictingE
             } else {
                 if (isDir) {
                     lastDirEntry = archiveEntry;
-                }
-                else if (!error) {
+                } else if (!error) {
                     conflictingEntries << archiveEntry;
                 }
             }
@@ -768,9 +750,9 @@ bool ArchiveModel::hasDuplicatedEntries(const QStringList &entries)
     return false;
 }
 
-QMap<QString, Archive::Entry*> ArchiveModel::entryMap(const QVector<Archive::Entry*> &entries)
+QMap<QString, Archive::Entry *> ArchiveModel::entryMap(const QVector<Archive::Entry *> &entries)
 {
-    QMap<QString, Archive::Entry*> map;
+    QMap<QString, Archive::Entry *> map;
     for (Archive::Entry *entry : entries) {
         map.insert(entry->fullPath(), entry);
     }
@@ -803,8 +785,8 @@ void ArchiveModel::slotCleanupEmptyDirs()
         }
     }
 
-    for (const QPersistentModelIndex& node : std::as_const(nodesToDelete)) {
-        Archive::Entry *rawEntry = static_cast<Archive::Entry*>(node.internalPointer());
+    for (const QPersistentModelIndex &node : std::as_const(nodesToDelete)) {
+        Archive::Entry *rawEntry = static_cast<Archive::Entry *>(node.internalPointer());
         qCDebug(ARK) << "Delete with parent entries " << rawEntry->getParent()->entries() << " and row " << rawEntry->row();
         beginRemoveRows(parent(node), rawEntry->row(), rawEntry->row());
         rawEntry->getParent()->removeEntryAt(rawEntry->row());
