@@ -20,13 +20,13 @@ using namespace Kerfuffle;
 
 K_PLUGIN_CLASS_WITH_JSON(CliPlugin, "kerfuffle_cli7z.json")
 
-CliPlugin::CliPlugin(QObject *parent, const QVariantList & args)
-        : CliInterface(parent, args)
-        , m_archiveType(ArchiveType7z)
-        , m_parseState(ParseStateTitle)
-        , m_binaryVariant(Undefined)
-        , m_linesComment(0)
-        , m_isFirstInformationEntry(true)
+CliPlugin::CliPlugin(QObject *parent, const QVariantList &args)
+    : CliInterface(parent, args)
+    , m_archiveType(ArchiveType7z)
+    , m_parseState(ParseStateTitle)
+    , m_binaryVariant(Undefined)
+    , m_linesComment(0)
+    , m_isFirstInformationEntry(true)
 {
     qCDebug(ARK) << "Loaded cli_7z plugin";
 
@@ -81,8 +81,7 @@ void CliPlugin::setupCliProperties()
     m_cliProps->setProperty("extractSwitchNoPreserve", QStringList{QStringLiteral("e")});
 
     m_cliProps->setProperty("listProgram", QStringLiteral("7z"));
-    m_cliProps->setProperty("listSwitch", QStringList{QStringLiteral("l"),
-                                                  QStringLiteral("-slt")});
+    m_cliProps->setProperty("listSwitch", QStringList{QStringLiteral("l"), QStringLiteral("-slt")});
 
     m_cliProps->setProperty("moveProgram", QStringLiteral("7z"));
     m_cliProps->setProperty("moveSwitch", QStringLiteral("rn"));
@@ -91,22 +90,25 @@ void CliPlugin::setupCliProperties()
     m_cliProps->setProperty("testSwitch", QStringLiteral("t"));
 
     m_cliProps->setProperty("passwordSwitch", QStringList{QStringLiteral("-p$Password")});
-    m_cliProps->setProperty("passwordSwitchHeaderEnc", QStringList{QStringLiteral("-p$Password"),
-                                                               QStringLiteral("-mhe=on")});
+    m_cliProps->setProperty("passwordSwitchHeaderEnc", QStringList{QStringLiteral("-p$Password"), QStringLiteral("-mhe=on")});
     m_cliProps->setProperty("compressionLevelSwitch", QStringLiteral("-mx=$CompressionLevel"));
-    m_cliProps->setProperty("compressionMethodSwitch", QHash<QString,QVariant>{{QStringLiteral("application/x-7z-compressed"), QStringLiteral("-m0=$CompressionMethod")},
-                                                                               {QStringLiteral("application/zip"), QStringLiteral("-mm=$CompressionMethod")}});
-    m_cliProps->setProperty("encryptionMethodSwitch", QHash<QString,QVariant>{{QStringLiteral("application/x-7z-compressed"), QString()},
-                                                                              {QStringLiteral("application/zip"), QStringLiteral("-mem=$EncryptionMethod")}});
+    m_cliProps->setProperty("compressionMethodSwitch",
+                            QHash<QString, QVariant>{{QStringLiteral("application/x-7z-compressed"), QStringLiteral("-m0=$CompressionMethod")},
+                                                     {QStringLiteral("application/zip"), QStringLiteral("-mm=$CompressionMethod")}});
+    m_cliProps->setProperty("encryptionMethodSwitch",
+                            QHash<QString, QVariant>{{QStringLiteral("application/x-7z-compressed"), QString()},
+                                                     {QStringLiteral("application/zip"), QStringLiteral("-mem=$EncryptionMethod")}});
     m_cliProps->setProperty("multiVolumeSwitch", QStringLiteral("-v$VolumeSizek"));
     m_cliProps->setProperty("testPassedPatterns", QStringList{QStringLiteral("^Everything is Ok$")});
-    m_cliProps->setProperty("fileExistsFileNameRegExp", QStringList{QStringLiteral("^file \\./(.*)$"),
-                                                                    QStringLiteral("^  Path:     \\./(.*)$")});
-    m_cliProps->setProperty("fileExistsInput", QStringList{QStringLiteral("Y"),   //Overwrite
-                                                       QStringLiteral("N"),   //Skip
-                                                       QStringLiteral("A"),   //Overwrite all
-                                                       QStringLiteral("S"),   //Autoskip
-                                                       QStringLiteral("Q")}); //Cancel
+    m_cliProps->setProperty("fileExistsFileNameRegExp", QStringList{QStringLiteral("^file \\./(.*)$"), QStringLiteral("^  Path:     \\./(.*)$")});
+    m_cliProps->setProperty("fileExistsInput",
+                            QStringList{
+                                QStringLiteral("Y"), // Overwrite
+                                QStringLiteral("N"), // Skip
+                                QStringLiteral("A"), // Overwrite all
+                                QStringLiteral("S"), // Autoskip
+                                QStringLiteral("Q"), // Cancel
+                            });
     m_cliProps->setProperty("multiVolumeSuffix", QStringList{QStringLiteral("$Suffix.001")});
 }
 
@@ -120,7 +122,7 @@ void CliPlugin::fixDirectoryFullName()
     }
 }
 
-bool CliPlugin::readListLine(const QString& line)
+bool CliPlugin::readListLine(const QString &line)
 {
     static const QLatin1String archiveInfoDelimiter1("--"); // 7z 9.13+
     static const QLatin1String archiveInfoDelimiter2("----"); // 7z 9.04
@@ -142,23 +144,21 @@ bool CliPlugin::readListLine(const QString& line)
             m_parseState = ParseStateHeader;
             const QString p7zipVersion = matchVersion.captured(1);
             qCDebug(ARK) << "p7zip version" << p7zipVersion << "detected";
-	    break;
+            break;
         }
-	matchVersion = rxVersionLine7z.match(line);
+        matchVersion = rxVersionLine7z.match(line);
         if (matchVersion.hasMatch()) {
             m_parseState = ParseStateHeader;
             const QString l7zipVersion = matchVersion.captured(1);
             qCDebug(ARK) << "7zip version" << l7zipVersion << "detected";
-	    break;
+            break;
         }
         break;
 
     case ParseStateHeader:
         if (line.startsWith(QLatin1String("Listing archive:"))) {
-            qCDebug(ARK) << "Archive name: "
-                         << line.right(line.size() - 16).trimmed();
-        } else if ((line == archiveInfoDelimiter1) ||
-                   (line == archiveInfoDelimiter2)) {
+            qCDebug(ARK) << "Archive name: " << line.right(line.size() - 16).trimmed();
+        } else if ((line == archiveInfoDelimiter1) || (line == archiveInfoDelimiter2)) {
             m_parseState = ParseStateArchiveInformation;
         } else if (line.contains(QLatin1String("Error: "))) {
             qCWarning(ARK) << line.mid(7);
@@ -228,8 +228,7 @@ bool CliPlugin::readListLine(const QString& line)
             m_currentArchiveEntry->compressedSizeIsSet = false;
         }
         if (line.startsWith(QLatin1String("Path = "))) {
-            const QString entryFilename =
-                QDir::fromNativeSeparators(line.mid(7).trimmed());
+            const QString entryFilename = QDir::fromNativeSeparators(line.mid(7).trimmed());
             m_currentArchiveEntry->setProperty("fullPath", entryFilename);
 
         } else if (line.startsWith(QLatin1String("Size = "))) {
@@ -244,8 +243,7 @@ bool CliPlugin::readListLine(const QString& line)
             }
 
         } else if (line.startsWith(QLatin1String("Modified = "))) {
-            m_currentArchiveEntry->setProperty("timestamp", QDateTime::fromString(line.mid(11).trimmed(),
-                                                                                  QStringLiteral("yyyy-MM-dd hh:mm:ss")));
+            m_currentArchiveEntry->setProperty("timestamp", QDateTime::fromString(line.mid(11).trimmed(), QStringLiteral("yyyy-MM-dd hh:mm:ss")));
 
         } else if (line.startsWith(QLatin1String("Folder = "))) {
             const QString isDirectoryStr = line.mid(9).trimmed();
@@ -263,8 +261,7 @@ bool CliPlugin::readListLine(const QString& line)
 
             if (attributes.contains(QLatin1Char('_'))) {
                 // Unix attributes
-                m_currentArchiveEntry->setProperty("permissions",
-                                                   attributes.mid(attributes.indexOf(QLatin1Char(' ')) + 1));
+                m_currentArchiveEntry->setProperty("permissions", attributes.mid(attributes.indexOf(QLatin1Char(' ')) + 1));
             } else {
                 // FAT attributes
                 m_currentArchiveEntry->setProperty("permissions", attributes);
@@ -282,17 +279,14 @@ bool CliPlugin::readListLine(const QString& line)
                 handleMethods(methods);
             }
 
-        } else if (line.startsWith(QLatin1String("Encrypted = ")) &&
-                   line.size() >= 13) {
+        } else if (line.startsWith(QLatin1String("Encrypted = ")) && line.size() >= 13) {
             m_currentArchiveEntry->setProperty("isPasswordProtected", line.at(12) == QLatin1Char('+'));
 
-        } else if (line.startsWith(QLatin1String("Block = ")) ||
-                   line.startsWith(QLatin1String("Version = "))) {
+        } else if (line.startsWith(QLatin1String("Block = ")) || line.startsWith(QLatin1String("Version = "))) {
             m_isFirstInformationEntry = true;
             if (!m_currentArchiveEntry->fullPath().isEmpty()) {
                 Q_EMIT entry(m_currentArchiveEntry);
-            }
-            else {
+            } else {
                 delete m_currentArchiveEntry;
             }
             m_currentArchiveEntry = nullptr;
@@ -310,8 +304,7 @@ bool CliPlugin::readExtractLine(const QString &line)
         return false;
     }
 
-    if (line.startsWith(QLatin1String("ERROR: CRC Failed")) ||
-        line.startsWith(QLatin1String("ERROR: Headers Error"))) {
+    if (line.startsWith(QLatin1String("ERROR: CRC Failed")) || line.startsWith(QLatin1String("ERROR: Headers Error"))) {
         Q_EMIT error(i18n("Extraction failed due to one or more corrupt files. Any extracted files may be damaged."));
         return false;
     }
@@ -321,8 +314,7 @@ bool CliPlugin::readExtractLine(const QString &line)
 
 bool CliPlugin::readDeleteLine(const QString &line)
 {
-    if (line.startsWith(QLatin1String("Error: ")) &&
-        line.endsWith(QLatin1String(" is not supported archive"))) {
+    if (line.startsWith(QLatin1String("Error: ")) && line.endsWith(QLatin1String(" is not supported archive"))) {
         Q_EMIT error(i18n("Delete operation failed. Try upgrading 7z or disabling the 7z plugin in the configuration dialog."));
         return false;
     }
@@ -333,7 +325,6 @@ bool CliPlugin::readDeleteLine(const QString &line)
 void CliPlugin::handleMethods(const QStringList &methods)
 {
     for (const QString &method : methods) {
-
         QRegularExpression rxEncMethod(QStringLiteral("^(7zAES|AES-128|AES-192|AES-256|ZipCrypto)$"));
         if (rxEncMethod.match(method).hasMatch()) {
             QRegularExpression rxAESMethods(QStringLiteral("^(AES-128|AES-192|AES-256)$"));
@@ -372,8 +363,7 @@ bool CliPlugin::isWrongPasswordMsg(const QString &line)
 
 bool CliPlugin::isCorruptArchiveMsg(const QString &line)
 {
-    return (line == QLatin1String("Unexpected end of archive") ||
-            line == QLatin1String("Headers Error"));
+    return (line == QLatin1String("Unexpected end of archive") || line == QLatin1String("Headers Error"));
 }
 
 bool CliPlugin::isDiskFullMsg(const QString &line)
@@ -383,14 +373,13 @@ bool CliPlugin::isDiskFullMsg(const QString &line)
 
 bool CliPlugin::isFileExistsMsg(const QString &line)
 {
-    return (line == QLatin1String("(Y)es / (N)o / (A)lways / (S)kip all / A(u)to rename all / (Q)uit? ") ||
-            line == QLatin1String("? (Y)es / (N)o / (A)lways / (S)kip all / A(u)to rename all / (Q)uit? "));
+    return (line == QLatin1String("(Y)es / (N)o / (A)lways / (S)kip all / A(u)to rename all / (Q)uit? ")
+            || line == QLatin1String("? (Y)es / (N)o / (A)lways / (S)kip all / A(u)to rename all / (Q)uit? "));
 }
 
 bool CliPlugin::isFileExistsFileName(const QString &line)
 {
-    return (line.startsWith(QLatin1String("file ./")) ||
-            line.startsWith(QLatin1String("  Path:     ./")));
+    return (line.startsWith(QLatin1String("file ./")) || line.startsWith(QLatin1String("  Path:     ./")));
 }
 
 #include "cliplugin.moc"
