@@ -9,28 +9,28 @@
  */
 
 #include "cliplugin.h"
-#include "ark_debug.h"
 #include "archiveentry.h"
+#include "ark_debug.h"
 
 #include <QDateTime>
 
 #include <KLocalizedString>
 #include <KPluginFactory>
 
-    using namespace Kerfuffle;
+using namespace Kerfuffle;
 
 K_PLUGIN_CLASS_WITH_JSON(CliPlugin, "kerfuffle_clirar.json")
 
-CliPlugin::CliPlugin(QObject *parent, const QVariantList& args)
-        : CliInterface(parent, args)
-        , m_parseState(ParseStateTitle)
-        , m_isUnrar5(false)
-        , m_isPasswordProtected(false)
-        , m_isSolid(false)
-        , m_isRAR5(false)
-        , m_isLocked(false)
-        , m_remainingIgnoreLines(1) //The first line of UNRAR output is empty.
-        , m_linesComment(0)
+CliPlugin::CliPlugin(QObject *parent, const QVariantList &args)
+    : CliInterface(parent, args)
+    , m_parseState(ParseStateTitle)
+    , m_isUnrar5(false)
+    , m_isPasswordProtected(false)
+    , m_isSolid(false)
+    , m_isRAR5(false)
+    , m_isLocked(false)
+    , m_remainingIgnoreLines(1) // The first line of UNRAR output is empty.
+    , m_linesComment(0)
 {
     qCDebug(ARK) << "Loaded cli_rar plugin";
 
@@ -66,16 +66,11 @@ void CliPlugin::setupCliProperties()
     m_cliProps->setProperty("deleteSwitch", QStringLiteral("d"));
 
     m_cliProps->setProperty("extractProgram", QStringLiteral("unrar"));
-    m_cliProps->setProperty("extractSwitch", QStringList{QStringLiteral("x"),
-                                                     QStringLiteral("-kb"),
-                                                     QStringLiteral("-p-")});
-    m_cliProps->setProperty("extractSwitchNoPreserve", QStringList{QStringLiteral("e"),
-                                                               QStringLiteral("-kb"),
-                                                               QStringLiteral("-p-")});
+    m_cliProps->setProperty("extractSwitch", QStringList{QStringLiteral("x"), QStringLiteral("-kb"), QStringLiteral("-p-")});
+    m_cliProps->setProperty("extractSwitchNoPreserve", QStringList{QStringLiteral("e"), QStringLiteral("-kb"), QStringLiteral("-p-")});
 
     m_cliProps->setProperty("listProgram", QStringLiteral("unrar"));
-    m_cliProps->setProperty("listSwitch", QStringList{QStringLiteral("vt"),
-                                                  QStringLiteral("-v")});
+    m_cliProps->setProperty("listSwitch", QStringList{QStringLiteral("vt"), QStringLiteral("-v")});
 
     m_cliProps->setProperty("moveProgram", QStringLiteral("rar"));
     m_cliProps->setProperty("moveSwitch", QStringLiteral("rn"));
@@ -83,31 +78,33 @@ void CliPlugin::setupCliProperties()
     m_cliProps->setProperty("testProgram", QStringLiteral("unrar"));
     m_cliProps->setProperty("testSwitch", QStringLiteral("t"));
 
-    m_cliProps->setProperty("commentSwitch", QStringList{QStringLiteral("c"),
-                                                     QStringLiteral("-z$CommentFile")});
+    m_cliProps->setProperty("commentSwitch", QStringList{QStringLiteral("c"), QStringLiteral("-z$CommentFile")});
 
     m_cliProps->setProperty("passwordSwitch", QStringList{QStringLiteral("-p$Password")});
     m_cliProps->setProperty("passwordSwitchHeaderEnc", QStringList{QStringLiteral("-hp$Password")});
 
     m_cliProps->setProperty("compressionLevelSwitch", QStringLiteral("-m$CompressionLevel"));
-    m_cliProps->setProperty("compressionMethodSwitch", QHash<QString,QVariant>{{QStringLiteral("application/vnd.rar"), QStringLiteral("-ma$CompressionMethod")},
-                                                                           {QStringLiteral("application/x-rar"), QStringLiteral("-ma$CompressionMethod")}});
+    m_cliProps->setProperty("compressionMethodSwitch",
+                            QHash<QString, QVariant>{{QStringLiteral("application/vnd.rar"), QStringLiteral("-ma$CompressionMethod")},
+                                                     {QStringLiteral("application/x-rar"), QStringLiteral("-ma$CompressionMethod")}});
     m_cliProps->setProperty("multiVolumeSwitch", QStringLiteral("-v$VolumeSizek"));
 
-
     m_cliProps->setProperty("testPassedPatterns", QStringList{QStringLiteral("^All OK$")});
-    m_cliProps->setProperty("fileExistsFileNameRegExp", QStringList{QStringLiteral("^(.+) already exists. Overwrite it"),  // unrar 3 & 4
-                                                                    QStringLiteral("^Would you like to replace the existing file (.+)$")}); // unrar 5
-    m_cliProps->setProperty("fileExistsInput", QStringList{QStringLiteral("Y"),   //Overwrite
-                                                       QStringLiteral("N"),   //Skip
-                                                       QStringLiteral("A"),   //Overwrite all
-                                                       QStringLiteral("E"),   //Autoskip
-                                                       QStringLiteral("Q")}); //Cancel
+    m_cliProps->setProperty("fileExistsFileNameRegExp",
+                            QStringList{QStringLiteral("^(.+) already exists. Overwrite it"), // unrar 3 & 4
+                                        QStringLiteral("^Would you like to replace the existing file (.+)$")}); // unrar 5
+    m_cliProps->setProperty("fileExistsInput",
+                            QStringList{
+                                QStringLiteral("Y"), // Overwrite
+                                QStringLiteral("N"), // Skip
+                                QStringLiteral("A"), // Overwrite all
+                                QStringLiteral("E"), // Autoskip
+                                QStringLiteral("Q"), // Cancel
+                            });
 
     // rar will sometimes create multi-volume archives where first volume is
     // called name.part1.rar and other times name.part01.rar.
-    m_cliProps->setProperty("multiVolumeSuffix", QStringList{QStringLiteral("part01.$Suffix"),
-                                                         QStringLiteral("part1.$Suffix")});
+    m_cliProps->setProperty("multiVolumeSuffix", QStringList{QStringLiteral("part01.$Suffix"), QStringLiteral("part1.$Suffix")});
 }
 
 bool CliPlugin::readListLine(const QString &line)
@@ -120,7 +117,6 @@ bool CliPlugin::readListLine(const QString &line)
 
     // Parse the title line, which contains the version of unrar.
     if (m_parseState == ParseStateTitle) {
-
         QRegularExpression rxVersionLine(QStringLiteral("^UNRAR (\\d+\\.\\d+)( beta \\d)? .*$"));
         QRegularExpressionMatch matchVersion = rxVersionLine.match(line);
 
@@ -134,15 +130,15 @@ bool CliPlugin::readListLine(const QString &line)
             } else {
                 qCDebug(ARK) << "Using UNRAR 4 parser";
             }
-        }  else {
+        } else {
             // If the second line doesn't contain an UNRAR title, something
             // is wrong.
             qCCritical(ARK) << "Failed to detect UNRAR output.";
             return false;
         }
 
-    // Or see what version of unrar we are dealing with and call specific
-    // handler functions.
+        // Or see what version of unrar we are dealing with and call specific
+        // handler functions.
     } else if (m_isUnrar5) {
         return handleUnrar5Line(line);
     } else {
@@ -159,7 +155,6 @@ bool CliPlugin::handleUnrar5Line(const QString &line)
     }
 
     switch (m_parseState) {
-
     // Parses the comment field.
     case ParseStateComment:
 
@@ -219,12 +214,11 @@ bool CliPlugin::handleUnrar5Line(const QString &line)
             m_parseState = ParseStateHeader;
             return true;
 
-        // Empty line indicates end of entry.
+            // Empty line indicates end of entry.
         } else if (line.trimmed().isEmpty() && !m_unrar5Details.isEmpty()) {
             handleUnrar5Entry();
 
         } else {
-
             // All detail lines should contain a colon.
             if (!line.contains(QLatin1Char(':'))) {
                 qCWarning(ARK) << "Unrecognized line:" << line;
@@ -233,8 +227,7 @@ bool CliPlugin::handleUnrar5Line(const QString &line)
 
             // The details are on separate lines, so we store them in the QHash
             // m_unrar5Details.
-            m_unrar5Details.insert(line.section(QLatin1Char(':'), 0, 0).trimmed().toLower(),
-                                   line.section(QLatin1Char(':'), 1).trimmed());
+            m_unrar5Details.insert(line.section(QLatin1Char(':'), 0, 0).trimmed().toLower(), line.section(QLatin1Char(':'), 1).trimmed());
         }
 
         break;
@@ -312,21 +305,19 @@ bool CliPlugin::handleUnrar4Line(const QString &line)
     QRegularExpressionMatch matchSubHeader;
 
     switch (m_parseState) {
-
     // Parses the comment field.
     case ParseStateComment:
 
         // unrar 4 outputs the following string when opening v5 RAR archives.
         if (line == QLatin1String("Unsupported archive format. Please update RAR to a newer version.")) {
-            Q_EMIT error(i18n("Your unrar executable is version %1, which is too old to handle this archive. Please update to a more recent version.",
-                            m_unrarVersion));
+            Q_EMIT error(
+                i18n("Your unrar executable is version %1, which is too old to handle this archive. Please update to a more recent version.", m_unrarVersion));
             return false;
         }
 
         // unrar 3 reports a non-RAR archive when opening v5 RAR archives.
         if (line.endsWith(QLatin1String(" is not RAR archive"))) {
-            Q_EMIT error(i18n("Unrar reported a non-RAR archive. The installed unrar version (%1) is old. Try updating your unrar.",
-                            m_unrarVersion));
+            Q_EMIT error(i18n("Unrar reported a non-RAR archive. The installed unrar version (%1) is old. Try updating your unrar.", m_unrarVersion));
             return false;
         }
 
@@ -335,7 +326,6 @@ bool CliPlugin::handleUnrar4Line(const QString &line)
         Q_EMIT compressionMethodFound(QStringLiteral("RAR4"));
 
         if (rxCommentEnd.match(line).hasMatch()) {
-
             if (line.startsWith(QLatin1String("Volume "))) {
                 m_numberOfVolumes++;
                 if (!isMultiVolume()) {
@@ -403,20 +393,20 @@ bool CliPlugin::handleUnrar4Line(const QString &line)
             m_parseState = ParseStateHeader;
             return true;
 
-        // Encrypted files are marked with an asterisk.
+            // Encrypted files are marked with an asterisk.
         } else if (line.startsWith(QLatin1Char('*'))) {
             m_isPasswordProtected = true;
-            m_unrar4Details.append(QString(line.trimmed()).remove(0, 1)); //Remove the asterisk
+            m_unrar4Details.append(QString(line.trimmed()).remove(0, 1)); // Remove the asterisk
             Q_EMIT encryptionMethodFound(QStringLiteral("AES128"));
 
-        // Entry names always start at the second position, so a line not
-        // starting with a space is not an entry name.
+            // Entry names always start at the second position, so a line not
+            // starting with a space is not an entry name.
         } else if (!line.startsWith(QLatin1Char(' '))) {
             qCWarning(ARK) << "Unrecognized line:" << line;
             return true;
 
-        // If we reach this, then we can assume the line is an entry name, so
-        // save it, and move on to the rest of the entry details.
+            // If we reach this, then we can assume the line is an entry name, so
+            // save it, and move on to the rest of the entry details.
         } else {
             m_unrar4Details.append(line.trimmed());
         }
@@ -442,8 +432,7 @@ bool CliPlugin::handleUnrar4Line(const QString &line)
         // In unrar 3 and 4 the details are on a single line, so we
         // pass a QStringList containing the details. We need to store
         // it due to symlinks (see below).
-        m_unrar4Details.append(line.split(QLatin1Char(' '),
-                                          Qt::SkipEmptyParts));
+        m_unrar4Details.append(line.split(QLatin1Char(' '), Qt::SkipEmptyParts));
 
         // The details line contains 9 fields, so m_unrar4Details
         // should now contain 9 + the filename = 10 strings. If not, this is
@@ -490,8 +479,7 @@ void CliPlugin::handleUnrar4Entry()
 {
     Archive::Entry *e = new Archive::Entry(this);
 
-    QDateTime ts = QDateTime::fromString(QString(m_unrar4Details.at(4) + QLatin1Char(' ') + m_unrar4Details.at(5)),
-                                         QStringLiteral("dd-MM-yy hh:mm"));
+    QDateTime ts = QDateTime::fromString(QString(m_unrar4Details.at(4) + QLatin1Char(' ') + m_unrar4Details.at(5)), QStringLiteral("dd-MM-yy hh:mm"));
     // Unrar 3 & 4 output dates with a 2-digit year but QDateTime takes it as
     // 19??. Let's take 1950 as cut-off; similar to KDateTime.
     // Hopefully no one will create rar archives in 2051 with unrar 4...
@@ -501,8 +489,7 @@ void CliPlugin::handleUnrar4Entry()
     }
     e->setProperty("timestamp", ts);
 
-    bool isDirectory = ((m_unrar4Details.at(6).at(0) == QLatin1Char('d')) ||
-                        (m_unrar4Details.at(6).at(1) == QLatin1Char('D')));
+    bool isDirectory = ((m_unrar4Details.at(6).at(0) == QLatin1Char('d')) || (m_unrar4Details.at(6).at(1) == QLatin1Char('D')));
     e->setProperty("isDirectory", isDirectory);
 
     if (isDirectory && !m_unrar4Details.at(0).endsWith(QLatin1Char('/'))) {
@@ -515,9 +502,7 @@ void CliPlugin::handleUnrar4Entry()
     // whether the archive's position in the volume is displayed
     // instead of the compression ratio.
     QString compressionRatio = m_unrar4Details.at(3);
-    if ((compressionRatio == QLatin1String("<--")) ||
-        (compressionRatio == QLatin1String("<->")) ||
-        (compressionRatio == QLatin1String("-->"))) {
+    if ((compressionRatio == QLatin1String("<--")) || (compressionRatio == QLatin1String("<->")) || (compressionRatio == QLatin1String("-->"))) {
         compressionRatio = QLatin1Char('0');
     } else {
         compressionRatio.chop(1); // Remove the '%'
@@ -582,9 +567,8 @@ bool CliPlugin::isWrongPasswordMsg(const QString &line)
 
 bool CliPlugin::isCorruptArchiveMsg(const QString &line)
 {
-    return (line == QLatin1String("Unexpected end of archive") ||
-            line.contains(QLatin1String("the file header is corrupt")) ||
-            line.endsWith(QLatin1String("checksum error")));
+    return (line == QLatin1String("Unexpected end of archive") || line.contains(QLatin1String("the file header is corrupt"))
+            || line.endsWith(QLatin1String("checksum error")));
 }
 
 bool CliPlugin::isDiskFullMsg(const QString &line)
